Class: Ivy4rJars
- Inherits:
-
Object
- Object
- Ivy4rJars
- Defined in:
- lib/ivy4r_jars.rb
Constant Summary collapse
- VERSION =
'1.2.0'
Class Method Summary collapse
-
.ant_home_dir ⇒ Object
Returns expanded path to directory that can be used as ANT_HOME for Antwrap.
-
.lib_dir ⇒ Object
Returns expanded path to directory containing the jars.
Class Method Details
.ant_home_dir ⇒ Object
Returns expanded path to directory that can be used as ANT_HOME for Antwrap.
12 13 14 |
# File 'lib/ivy4r_jars.rb', line 12 def ant_home_dir @ant_home_dir ||= File.dirname(lib_dir) end |
.lib_dir ⇒ Object
Returns expanded path to directory containing the jars
6 7 8 |
# File 'lib/ivy4r_jars.rb', line 6 def lib_dir @lib_dir ||= File.(File.dirname(__FILE__)) end |